@@ -33,12 +33,21 @@
             cgi:uploads cgi:upload
             cgi:cookie-names
             cgi:cookies cgi:cookie)
-  #:autoload (www server-utils parse-request) (alist<-query read-body)
+  #:use-module ((www server-utils parse-request) #:select (alist<-query
+                                                           read-body))
   #:autoload (www server-utils cookies) (simple-parse-cookies)
   #:autoload (www server-utils form-2-form) (parse-form)
-  #:use-module (ice-9 and-let-star)
-  #:use-module (srfi srfi-13)
-  #:use-module (srfi srfi-14))
+  #:use-module ((srfi srfi-2) #:select (and-let*))
+  #:use-module ((srfi srfi-13) #:select (string-join
+                                         substring/shared
+                                         string-prefix-ci?
+                                         string-index
+                                         string-upcase
+                                         string-tokenize))
+  #:use-module ((srfi srfi-14) #:select (char-set
+                                         char-set-adjoin
+                                         char-set-complement
+                                         char-set:whitespace)))
 
 (define (collate alist)
   (let ((rv '()))
