@@ -39,6 +39,7 @@
             get-body-proc
             read-headers/get-body
             out!)
+  #:use-module (ice-9 binary-ports)
   #:use-module (ice-9 optargs)
   #:use-module ((ice-9 rw) #:select (read-string!/partial
                                      write-string/partial))
@@ -51,6 +52,7 @@
                                         u8vector-set!))
   #:use-module ((srfi srfi-11) #:select (let-values))
   #:use-module ((srfi srfi-13) #:select (string-concatenate-reverse
+                                         string-concatenate
                                          string-take
                                          string-suffix?
                                          string-index
@@ -59,7 +61,8 @@
                                          string-trim-right
                                          string-trim-both
                                          substring/shared))
-  #:use-module ((srfi srfi-14) #:select (char-set:whitespace)))
+  #:use-module ((srfi srfi-14) #:select (char-set:whitespace
+                                         char-set-contains?)))
 
 (define CR "\r")
 
@@ -213,6 +216,9 @@
       (x)
       x))
 
+(define u8-read!-all uniform-vector-read!)
+(define u8-write-all uniform-vector-write)
+
 (define (get-body-proc sock hsym headers)
 
   (define (string-read!/partial s)
@@ -260,7 +266,7 @@
           ((memq 'u8 options)
            (motion (append `(custom ,(lambda ()
                                        (values make-u8vector
-                                               uniform-vector-read!
+                                               u8-read!-all
                                                u8-concatenate-reverse
                                                sub-u8)))
                            (delq 'u8 options))))
@@ -349,8 +355,8 @@
          (headers (read-headers sock hsym))
          (get-body (get-body-proc sock hsym headers)))
     (values headers
-            (and (or (not request)
-                     (let-values (((method rcode) request))
+            (and (or (not (thunk? request))
+                     (let-values (((method rcode) (request)))
                        ;; Sometimes no body is indicated.
                        ;; See RFC 2068: Section 4.3 "Message Body".
                        (not (or (eq? 'HEAD method)
@@ -409,7 +415,7 @@
                 (let ((lengths (map u8vector-length vectors)))
                   ;; move!
                   (x-move vectors (lambda (sock)
-                                    (uniform-vector-write
+                                    (u8-write-all
                                      (pop vectors)
                                      sock))))))
           ((or (and (string? body) (list body))
