@@ -48,9 +48,10 @@
   #:autoload (www post) (formatted-form-for-http:post-form)
   #:use-module ((srfi srfi-1) #:select (car+cdr))
   #:use-module ((srfi srfi-11) #:select (let-values))
-  #:use-module (www url)
-  #:use-module (ice-9 optargs)
-  #:use-module (ice-9 rw))
+  #:use-module ((www url) #:select (url:host
+                                    url:port
+                                    url:path))
+  #:use-module (ice-9 optargs))
 
 (define (fs s . args)
   (apply simple-format #f s args))
@@ -324,7 +325,8 @@
     (let-values (((rvers rcode rtext) (read-three-part-line sock)))
       (let ((numeric (string->number rcode)))
         (let-values (((headers body) (read-headers/get-body
-                                      sock s2s (values method numeric))))
+                                      sock s2s (lambda ()
+                                                 (values method numeric)))))
           (make-message rvers numeric rtext headers body))))))
 
 ;; Receive the @var{pending} (from @code{send-request}) response.
