@@ -27,8 +27,15 @@
   #:export (www:set-protocol-handler!
             www:get
             www:http-head-get)
-  #:use-module (www http)
-  #:use-module (www url)
+  #:use-module ((www http) #:select (http:message-body
+                                     http:message-headers
+                                     http:head
+                                     http:get))
+  #:use-module ((www url) #:select (url:scheme
+                                    url:host
+                                    url:port
+                                    url:path
+                                    url:parse))
   #:use-module (ice-9 optargs))
 
 (define dispatch-table
@@ -64,7 +71,6 @@
                      (url:path url))
              (error "unknown URL scheme" (url:scheme url))))))))
 
-
 ;; Parse @var{url-string} into portions; issue an "HTTP HEAD" request.
 ;; Signal error if the scheme for @var{url-string} is not @code{http}.
 ;; Optional second arg @code{alist?} non-@code{#f} means return only the
